﻿Imports Infragistics.UltraChart.Core.Layers
Imports Infragistics.UltraChart.Resources
Imports Infragistics.UltraChart.Core
Imports Infragistics.UltraChart.Core.Primitives
Imports Infragistics.UltraChart.Shared.Styles
Imports Infragistics.UltraChart.Resources.Appearance
Imports Infragistics.UltraChart.Core.ColorModel
Imports Infragistics.UltraChart.Data

Public Class Form1

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim boxSeries As New BoxSetSeries()

        boxSeries.BoxSets.Add(New BoxSet("First", 1, 4, 6, 8, 11))
        boxSeries.BoxSets.Add(New BoxSet("Second", 4, 8, 10, 14, 18))
        boxSeries.BoxSets.Add(New BoxSet("Third", 7, 12, 16, 20, 25))
        boxSeries.BoxSets.Add(New BoxSet("Fourth", 2.0, 12, 19, 24, 30))

        With UltraChart1
            .ChartType = ChartType.BoxChart
            .Series.Add(boxSeries)
            .BoxChart.BoxWidthFactor = 0.75

            .Tooltips.Format = TooltipStyle.DataValue
            .Tooltips.Display = TooltipDisplay.MouseMove

            ' Add layer to display the X
            .Layer.Add("MyTestLayer", New MyTestLayer())
            .UserLayerIndex = New String() {"Default", "MyTestLayer"}
            .InvalidateLayers()

        End With
    End Sub
End Class


Public Class MyTestLayer
    Implements ILayer


    Public Sub FillSceneGraph(ByVal scene As SceneGraph) Implements Infragistics.UltraChart.Core.Layers.ILayer.FillSceneGraph
        Dim allBoxes As New List(Of Box)
        For Each p As Primitive In scene
            If (TypeOf p Is Box) Then
                Dim b As Box = CType(p, Box)
                ' exclude the chart area (which is also a box)
                If b.rect.X <> 0 AndAlso b.rect.Y <> 0 Then
                    allBoxes.Add(b)
                End If
            End If
        Next p

        For Each bx As Box In allBoxes
            ' Just offset the X a little outside of the box
            Dim centerX As Integer = Convert.ToInt32(bx.rect.X - 10)
            Dim centerY As Integer = Convert.ToInt32(bx.rect.Y - 10)

            Dim sym As New Symbol(New Point(centerX, centerY), SymbolIcon.X, SymbolIconSize.Medium)

            With sym
                .PE.Stroke = Color.Blue
                .PE.Fill = .PE.Stroke
                .Layer = Me
                .Row = bx.Row
                .Value = bx.Value
                .Column = bx.Column
                .Caps = PCaps.HitTest Or PCaps.Tooltip
                .DataPoint = New NumericDataPoint(Convert.ToDouble(centerX), centerX.ToString(), False)
            End With
            scene.Add(sym)
        Next bx

    End Sub

#Region "Standard ILayer Implementation"
#Region "Private fields for storage of properties"
    Private _chartColorModel As ColorModel.IColorModel
    Private _chartComponent As IChartComponent = Nothing
    Private _chartCore As ChartCore = Nothing
    Private _chartData As Infragistics.UltraChart.Data.IChartData
    Private _grid As Hashtable = New Hashtable
    Private _layerName As String = String.Empty
    Private _outerBounds As Rectangle = New Rectangle(0, 0, 0, 0)
    Private _innerBounds As Rectangle = New Rectangle(0, 0, 0, 0)
    Private _visible As Boolean
#End Region

#Region "ILayer members"
    Public Property ChartColorModel() As ColorModel.IColorModel Implements Infragistics.UltraChart.Core.Layers.ILayer.ChartColorModel
        Get
            Return _chartColorModel
        End Get
        Set(ByVal Value As Infragistics.UltraChart.Core.ColorModel.IColorModel)
            _chartColorModel = Value
        End Set
    End Property

    Public Property ChartComponent() As IChartComponent Implements Infragistics.UltraChart.Core.Layers.ILayer.ChartComponent
        Get
            Return _chartComponent
        End Get
        Set(ByVal Value As Infragistics.UltraChart.Resources.IChartComponent)
            _chartComponent = Value
        End Set
    End Property

    Public Property ChartCore() As ChartCore Implements Infragistics.UltraChart.Core.Layers.ILayer.ChartCore
        Get
            Return _chartCore
        End Get
        Set(ByVal Value As Infragistics.UltraChart.Core.ChartCore)
            _chartCore = Value
        End Set
    End Property

    Public Property ChartData() As Infragistics.UltraChart.Data.IChartData Implements Infragistics.UltraChart.Core.Layers.ILayer.ChartData
        Get
            Return _chartData
        End Get
        Set(ByVal Value As Infragistics.UltraChart.Data.IChartData)
            _chartData = Value
        End Set
    End Property

    Public Function GetDataInvalidMessage() As String Implements Infragistics.UltraChart.Core.Layers.ILayer.GetDataInvalidMessage
        Return "Invalid Data."
    End Function

    Public Property Visible() As Boolean Implements Infragistics.UltraChart.Core.Layers.ILayer.Visible
        Get
            Return _visible
        End Get
        Set(ByVal Value As Boolean)
            _visible = Value
        End Set
    End Property

    Public Property Grid() As System.Collections.Hashtable Implements Infragistics.UltraChart.Core.Layers.ILayer.Grid
        Get
            Return _grid
        End Get
        Set(ByVal Value As System.Collections.Hashtable)
            _grid = Value
        End Set
    End Property

    Public Property LayerID() As String Implements Infragistics.UltraChart.Core.Layers.ILayer.LayerID
        Get
            Return _layerName
        End Get
        Set(ByVal Value As String)
            _layerName = Value
        End Set
    End Property

    Public Property OuterBound() As System.Drawing.Rectangle Implements Infragistics.UltraChart.Core.Layers.ILayer.OuterBound
        Get
            Return _outerBounds
        End Get
        Set(ByVal Value As System.Drawing.Rectangle)
            _outerBounds = Value
            CalculateInnerBounds()
        End Set
    End Property

    Public Function GetInnerBounds() As System.Drawing.Rectangle Implements Infragistics.UltraChart.Core.Layers.ILayer.GetInnerBounds
        Return _innerBounds
    End Function
#End Region

    Protected Sub CalculateInnerBounds()
        _innerBounds = New Rectangle(_outerBounds.X, _outerBounds.Y, _outerBounds.Width, _outerBounds.Height)
    End Sub
#End Region
End Class